@@ -15,7 +15,7 @@ use List::Compare;
 use List::MoreUtils qw(none uniq lastval);
 use Scalar::Util    qw(weaken);
 
-our $VERSION = '1.90';
+our $VERSION = '1.91';
 
 Travel::Status::DE::IRIS::Result->mk_ro_accessors(
 	qw(arrival arrival_delay arrival_has_realtime arrival_is_additional arrival_is_cancelled arrival_hidden
@@ -944,7 +944,7 @@ arrival/departure received by Travel::Status::DE::IRIS
 
 =head1 VERSION
 
-version 1.90
+version 1.91
 
 =head1 DESCRIPTION
 
@@ -1250,7 +1250,7 @@ train starts here.
 
 =item $result->sched_departure
 
-DateTime(3pm) object for the scehduled departure date and time. undef if the
+DateTime(3pm) object for the scheduled departure date and time. undef if the
 train ends here.
 
 =item $result->sched_platform
